<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Вилучити все</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation>Згорнути</translation>
    </message>
    <message>
        <source>More</source>
        <translation>Більше</translation>
    </message>
</context>
<context>
    <name>NotifyCenter</name>
    <message>
        <source>No recent notifications</source>
        <translation>Немає нещодавніх сповіщень</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Центр сповіщень</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Вилучити все</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation>Згорнути</translation>
    </message>
    <message>
        <source>More</source>
        <translation>Більше</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Відшпилити</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Пришпилити</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Параметри сповіщень</translation>
    </message>
</context>
<context>
    <name>NotifyViewDelegate</name>
    <message>
        <source>Clean All</source>
        <translation>Вилучити усе</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Щойно</translation>
    </message>
</context>
</TS>
